@@ -1,6 +1,6 @@
 package App::Pinto::Admin::Command::verify;
 
-# ABSTRACT: report distributions that are missing
+# ABSTRACT: verify that all the indexed distributions are present
 
 use strict;
 use warnings;
@@ -11,10 +11,27 @@ use base 'App::Pinto::Admin::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.040_001'; # VERSION
+our $VERSION = '0.009'; # VERSION
 
 #-----------------------------------------------------------------------------
 
+
+sub validate_args {
+    my ($self, $opt, $args) = @_;
+    $self->usage_error("Arguments are not allowed") if @{ $args };
+    return 1;
+}
+
+#------------------------------------------------------------------------------
+
+sub execute {
+    my ($self, $opts, $args) = @_;
+    $self->pinto( $opts )->verify();
+    return 0;  # TODO: exit non-zero if verification fails!
+}
+
+#------------------------------------------------------------------------------
+
 1;
 
 
@@ -25,35 +42,11 @@ our $VERSION = '0.040_001'; # VERSION
 
 =head1 NAME
 
-App::Pinto::Admin::Command::verify - report distributions that are missing
+App::Pinto::Admin::Command::verify - verify that all the indexed distributions are present
 
 =head1 VERSION
 
-version 0.040_001
-
-=head1 SYNOPSIS
-
-  pinto-admin --root=/some/dir verify
-
-=head1 DESCRIPTION
-
-This command reports distributions that are defined in the repository
-database, but the archives are not actually present.  This could occur
-when L<Pinto> aborts unexpectedly due to an exception or you terminate
-a command prematurely.
-
-At the moment, it isn't clear how to fix this situation.  In a future
-release you might be able to replace the archive for the distribution.
-But for now, this command simply lets you know if something has gone
-wrong in your repository.
-
-=head1 COMMAND ARGUMENTS
-
-None
-
-=head1 COMMAND OPTIONS
-
-None
+version 0.009
 
 =head1 AUTHOR
 
@@ -70,4 +63,3 @@ the same terms as the Perl 5 programming language system itself.
 
 
 __END__
-
