@@ -5,6 +5,7 @@ package Pinto;
 use Moose;
 
 use Carp;
+use Class::Load;
 use Path::Class;
 
 use Pinto::ActionFactory;
@@ -14,11 +15,12 @@ use namespace::autoclean;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.008'; # VERSION
+our $VERSION = '0.009'; # VERSION
 
 #------------------------------------------------------------------------------
 # Moose attributes
 
+# TODO: make private
 has action_factory => (
     is        => 'ro',
     isa       => 'Pinto::ActionFactory',
@@ -29,6 +31,7 @@ has action_factory => (
 
 #------------------------------------------------------------------------------
 
+# TODO: make private
 has action_batch => (
     is         => 'ro',
     isa        => 'Pinto::ActionBatch',
@@ -39,6 +42,7 @@ has action_batch => (
 
 #------------------------------------------------------------------------------
 
+# TODO: make private
 has idxmgr => (
     is       => 'ro',
     isa      => 'Pinto::IndexManager',
@@ -48,6 +52,7 @@ has idxmgr => (
 
 #------------------------------------------------------------------------------
 
+# TODO: make private
 has store => (
     is       => 'ro',
     isa      => 'Pinto::Store',
@@ -109,7 +114,7 @@ sub create {
 
     # HACK...I want to do this before checking out from VCS
     my $local = Path::Class::dir( $self->config()->local() );
-    die "Looks like you already have a repository at $local\n"
+    croak "A repository already exists at $local"
         if -e file($local, qw(modules 02packages.details.txt.gz));
 
     $self->enqueue( $self->create_action('Create') );
@@ -136,10 +141,15 @@ sub mirror {
 sub add {
     my ($self, %args) = @_;
 
-    my $file = $args{file};
-    $file = [$file] if not ref $file;
+    my $dists = delete $args{dists};
+    $dists = [$dists] if ref $dists ne 'ARRAY';
+
+    # TODO: Allow $dist to be a URL (http://, ftp://, file://).
+
+    for my $dist ( @{$dists} ) {
+        $self->enqueue( $self->create_action('Add', dist => $dist, %args) );
+    }
 
-    $self->enqueue( $self->create_action('Add', file => $_) ) for @{ $file };
     $self->run();
 
     return $self;
@@ -151,10 +161,13 @@ sub add {
 sub remove {
     my ($self, %args) = @_;
 
-    my $package = $args{package};
-    $package = [$package] if not ref $package;
+    my $packages = delete $args{packages};
+    $packages = [$packages] if ref $packages ne 'ARRAY';
+
+    for my $pkg ( @{$packages} ) {
+        $self->enqueue( $self->create_action('Remove', package => $pkg, %args) );
+    }
 
-    $self->enqueue( $self->create_action('Remove', package => $_) ) for @{ $package };
     $self->run();
 
     return $self;
@@ -201,15 +214,16 @@ sub verify {
 __PACKAGE__->meta->make_immutable();
 
 #-----------------------------------------------------------------------------
+
 1;
 
 
 
 =pod
 
-=for :stopwords Jeffrey Ryan Thalhammer Imaginative Software Systems cpan testmatrix url
-annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata
-placeholders
+=for :stopwords Jeffrey Ryan Thalhammer Imaginative Software Systems Genentech Hartzell
+Walde Sorichetti PASSed cpan testmatrix url annocpan anno bugtracker rt
+cpants kwalitee diff irc mailto metadata placeholders
 
 =head1 NAME
 
@@ -217,18 +231,15 @@ Pinto - Perl distribution repository manager
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
-=head1 DESCRIPTION
+=head1 SYNOPSIS
 
-You probably want to look at the documentation for L<pinto>.  This is
-a private module (for now) and the interface is subject to change.  So
-the API documentation is purely for my own reference.  But this
-document does explain what Pinto does and why it exists, so feel free
-to read on anyway.
-
-This is a work in progress.  Comments, criticisms, and suggestions
-are always welcome.  Feel free to contact C<thaljef@cpan.org>.
+You probably want to look at the documentation for L<pinto-admin>.
+All the modules in this distribution are private (for now).  So the
+API documentation is purely for my own reference.  But this document
+does explain what Pinto does and why it exists, so feel free to read
+on anyway.
 
 =head1 METHODS
 
@@ -238,13 +249,14 @@ Creates a new empty repository.
 
 =head2 mirror()
 
-Populates your repository with the latest version of all packages
-found on the CPAN mirror.  Your locally added packages will always
-mask those pulled from the mirror.
+Populates your repository with the latest version of all distributions
+found in the foreign repository (which is usually a CPAN mirror).  Your
+locally added distributions will always mask those mirrored from the
+remote repository.
 
-=head2 add(file => 'YourDist.tar.gz', author => 'SOMEONE')
+=head2 add(dists => ['YourDist.tar.gz'], author => 'SOMEONE')
 
-=head2 remove(package => 'Some::Package', author => 'SOMEONE')
+=head2 remove(packages => ['Some::Package'], author => 'SOMEONE')
 
 =head2 clean()
 
@@ -252,125 +264,38 @@ mask those pulled from the mirror.
 
 =head2 verify()
 
-=head1 TERMINOLOGY
+=head1 DISCUSSION
 
-Some of the terms around CPAN are frequently misused.  So for the
-purpose of this document, I am going to define some terms.  I am not
-saying that these are necessarily the "correct" definitions, but
-this is what I mean when I use them.
+L<Pinto> is a set of tools for creating and managing a CPAN-style
+repository.  This repository can contain just your own private
+distributions, or you can fill it with the latest ones from a CPAN
+mirror, or both.  You can then use your favorite CPAN client to
+fetch distributions from your repository and install them as you
+normally would.
 
-=over 4
+L<Pinto> shares a lot of DNA with L<CPAN::Site>, L<CPAN::Mini>, and
+L<CPAN::Mini::Inject>.  But I wasn't entirely satisfied with those, so
+I built a (hopefully better) mousetrap.
 
-=item package
+L<Pinto> is B<not> magic pixie dust though.  It does not guarantee
+that you will always have a working stack of distributions.  It is
+still up to you to figure out what to put in your repository.
+L<Pinto> just gives you a set of tools for doing that in a controlled
+manner.
 
-A "package" is the name that appears in a C<package> statement.  This
-is what PAUSE indexes, and this is what you usually ask L<cpan> or
-L<cpanm> to install for you.
-
-=item module
-
-A "module" is the name that appears in a C<use> or (sometimes)
-C<require> statement, and it always corresponds to a physical file
-somewhere.  A module usually contains only one package, and the name
-of the module usually matches the name of the package.  But sometimes,
-a module may contain many packages with completely arbitrary names.
-
-=item distribution 
-
-An "distribution" is a collection of Perl modules that have been packaged
-in a particular structure.  This is what you get when you run C<"make
-dist"> or C<"./Build dist">.  Distributions may come from a "mirror",
-or you may create your own.
-
-=item repository
-
-A "repository" is a collection of distributions that are organized in a
-particular structure, and having an index describing which packages
-are contained in each distribution.  This is where L<cpan> and L<cpanm>
-get the packages from.
-
-=item mirror
-
-A "mirror" is a copy of a public CPAN repository
-(e.g. http://cpan.perl.org).  Every "mirror" is a "repository", but
-not every "repository" is a "mirror".
-
-=back
-
-=head1 RULES
-
-There are certain rules that govern how the indexes are managed.
-These rules are intended to ensure that folks pulling packages from
-your repository will always get the *right* packages (according to my
-definitionof "right").  Also, the rules attempt to make Pinto behave
-somewhat like PAUSE does.
-
-=over 4
-
-=item A local package always masks a mirrored package, and all other
-packages that are in the same distribution with the mirrored package.
-
-This rule is key, so pay attention.  If the CPAN mirror has a distribution
-that contains both C<Foo> and C<Bar> packages, and you add your own
-distribution that contains C<Foo> package, then both the C<Foo> and C<Bar>
-mirroed packages will be removed from your index.  This ensures that
-anyone pulling packages from your repository will always get *your*
-version of C<Foo>.  But as a result, they'll never be able to get
-C<Bar>.
-
-=item You can never add an distribution with the same name twice.
-
-Most distribtuion-building tools will put some kind of version number in
-the name of the distribution, so this is rarely a problem.
-
-=item Only the original author of a local package can add a newer
-version of it.
-
-Ownership is given on a first-come basis, just like PAUSE.  So if
-C<SALLY> is the first author to add local package C<Foo::Bar> to the
-repository, then only C<SALLY> can ever add that package again.
-
-=item Only the original author of a local package can remove it.
-
-Just like when adding new versions of a local package, only the
-original author can remove it.
-
-=back
+This is a work in progress.  Comments, criticisms, and suggestions
+are always welcome.  Feel free to contact C<thaljef@cpan.org>.
 
 =head1 WHY IS IT CALLED "Pinto"
 
 The term "CPAN" is heavily overloaded.  In some contexts, it means the
 L<CPAN> module or the L<cpan> utility.  In other contexts, it means a
-mirror like L<http://cpan.perl.org> or a site like
+mirror like L<http://cpan.perl.org> or a web site like
 L<http://search.cpan.org>.
 
-I wanted to avoid confusion, so I picked a name that has no connection
-to "CPAN" at all.  "Pinto" is a nickname that I sometimes call my son,
-Wesley.
-
-=head1 TODO
-
-=over 4
-
-=item Enable plugins for visiting and filtering
-
-=item Implement Pinto::Store::Git
-
-=item Fix my Moose abuses
-
-=item Consider storing indexes in a DB, instead of files
-
-=item Automatically fetch dependecies when adding *VERY COOL*
-
-=item New command for listing conflicts between local and mirrored index
-
-=item Make file/directory permissions configurable
-
-=item Need more error checking and logging
-
-=item Lots of tests to write
-
-=back
+I wanted to avoid all that confusion, so I picked a name that has no
+connection to "CPAN" at all.  "Pinto" is a nickname that I sometimes
+call my son, Wesley.
 
 =head1 THANKS
 
@@ -382,6 +307,8 @@ Wesley.
 
 =item Shawn Sorichetti & Christian Walde - for creating CPAN::Mini::Inject
 
+=item George Hartzell @ Genentech - for sponsoring this project
+
 =back
 
 =head1 SUPPORT
