@@ -14,12 +14,12 @@ use namespace::autoclean;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.008'; # VERSION
+our $VERSION = '0.009'; # VERSION
 
 #------------------------------------------------------------------------------
 # Attrbutes
 
-has file => (
+has dist => (
     is       => 'ro',
     isa      => File,
     required => 1,
@@ -43,17 +43,16 @@ sub _build_author { return shift()->config->author() }
 override execute => sub {
     my ($self) = @_;
 
-    my $local   = $self->config->local();
-    my $cleanup = !$self->config->nocleanup();
-    my $author  = $self->author();
-    my $file    = $self->file();
+    my $local     = $self->config->local();
+    my $cleanup   = not $self->config->nocleanup();
+    my $author    = $self->author();
+    my $dist_file = $self->dist();
 
+    my $added   = Pinto::Distribution->new_from_file(file => $dist_file, author => $author);
+    my @removed = $self->idxmgr->add_local_distribution(dist => $added);
+    $self->logger->info(sprintf "Adding $added with %i packages", $added->package_count());
 
-    my $added   = Pinto::Distribution->new_from_file( file   => $file, author => $author );
-    my @removed = $self->idxmgr->add_local_distribution( dist => $added );
-    $self->logger->log(sprintf "Adding $added with %i packages", $added->package_count());
-
-    $self->store->add( file => $added->path($local), source => $file );
+    $self->store->add( file => $added->path($local), source => $dist_file );
     $cleanup && $self->store->remove( file => $_->path($local) ) for @removed;
 
     $self->add_message( Pinto::Util::added_dist_message($added) );
@@ -81,7 +80,7 @@ Pinto::Action::Add - An action to add one distribution to the repository
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 AUTHOR
 
