@@ -1,10 +1,11 @@
 package Pinto::Action::Mirror;
 
-# ABSTRACT: An action to fill the repository from a mirror
+# ABSTRACT: An action to mirror a remote repository into your local one
 
 use Moose;
 
 use URI;
+use Try::Tiny;
 
 use Pinto::Util;
 use Pinto::UserAgent;
@@ -15,16 +16,12 @@ use namespace::autoclean;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.008'; # VERSION
+our $VERSION = '0.009'; # VERSION
 
 #------------------------------------------------------------------------------
+# Moose Roles
 
-has 'ua'      => (
-    is         => 'ro',
-    isa        => 'Pinto::UserAgent',
-    default    => sub { Pinto::UserAgent->new() },
-    init_arg   => undef,
-);
+with qw(Pinto::Role::Downloadable);
 
 #------------------------------------------------------------------------------
 
@@ -33,37 +30,45 @@ sub execute {
 
     my $idxmgr  = $self->idxmgr();
     my $changes = $idxmgr->update_mirror_index() or return 0;
-    $changes   += $self->_do_mirror($_) for $idxmgr->dists_to_mirror();
+    my @dists   = $idxmgr->dists_to_mirror();
 
-    my $message = sprintf 'Updated to latest mirror of %s', $self->mirror();
-    $self->_set_message($message);
+    for my $dist ( @dists ) {
+        try   { $changes += $self->_do_fetch($dist) }
+        catch { $self->logger->whine("Download of $dist failed: $_") };
+    }
+
+    if ($changes) {
+        my $count  = @dists;
+        my $source = $self->config->source();
+        $self->add_message("Mirrored $count distributions from $source");
+    }
+
+    # Don't include an index change, just because --force was on
+    $changes -= $self->config->force();
 
     return $changes;
 }
 
 #------------------------------------------------------------------------------
 
-sub _do_mirror {
+sub _do_fetch {
     my ($self, $dist) = @_;
 
     my $local   = $self->config->local();
-    my $mirror  = $self->config->mirror();
+    my $source  = $self->config->source();
     my $cleanup = !$self->config->nocleanup();
 
-    my $url = $dist->url($mirror);
+    my $url = $dist->url($source);
     my $destination = $dist->path($local);
-    next if -e $destination;
+    return 0 if -e $destination;
 
-    my $changes_were_made = 0;
-    if ( $self->ua->mirror(url => $url, to => $destination, croak => 0) ) {
-        $self->logger->log("Mirrored distribution $dist");
-        $self->store->add(file => $destination);
-        my @removed = $self->idxmgr->add_mirrored_distribution(dist => $dist);
-        $cleanup && $self->store->remove(file => $_->path($local)) for @removed;
-        $changes_were_made++;
-    }
+    $self->fetch(url => $url, to => $destination) or return 0;
+    $self->store->add(file => $destination);
 
-    return $changes_were_made;
+    my @removed = $self->idxmgr->add_mirrored_distribution(dist => $dist);
+    $cleanup && $self->store->remove(file => $_->path($local)) for @removed;
+
+    return 1;
 }
 
 #------------------------------------------------------------------------------
@@ -82,11 +87,11 @@ __PACKAGE__->meta->make_immutable();
 
 =head1 NAME
 
-Pinto::Action::Mirror - An action to fill the repository from a mirror
+Pinto::Action::Mirror - An action to mirror a remote repository into your local one
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 AUTHOR
 
