@@ -5,11 +5,13 @@ package Pinto::Logger;
 use Moose;
 use MooseX::Types::Moose qw(Int);
 
+use Readonly;
+
 use namespace::autoclean;
 
 #-----------------------------------------------------------------------------
 
-our $VERSION = '0.008'; # VERSION
+our $VERSION = '0.009'; # VERSION
 
 #-----------------------------------------------------------------------------
 # Moose attributes
@@ -26,12 +28,20 @@ has log_level => (
 
 with qw(Pinto::Role::Configurable);
 
+#-----------------------------------------------------------------------------
+
+Readonly my $LOG_LEVEL_QUIET => -2;
+Readonly my $LOG_LEVEL_WARN  => -1;
+Readonly my $LOG_LEVEL_INFO  =>  0;
+Readonly my $LOG_LEVEL_DEBUG =>  1;
+
 #-----------------------------------------------------------------------------
 # Builders
 
 sub _build_log_level {
     my ($self) = @_;
-    return -2 if $self->config->quiet();
+
+    return $LOG_LEVEL_QUIET if $self->config->quiet();
     return $self->config->verbose();
 }
 
@@ -40,36 +50,47 @@ sub _build_log_level {
 
 sub _logit {
     my ($message) = @_;
-    print "$message\n";
+
+    return print "$message\n";
 }
 
 #-----------------------------------------------------------------------------
 # Public methods
 
 sub debug {
-    my ($self, $message, $opts) = @_;
-    _logit($message, $opts) if $self->log_level() >= 1;
-}
-
-#-----------------------------------------------------------------------------
-
-sub log {
-    my ($self, $message, $opts) = @_;
-    _logit($message, $opts) if $self->log_level() >= 0;
-}
-
-#-----------------------------------------------------------------------------
-
-sub warn {
     my ($self, $message) = @_;
-    CORE::warn "$message\n" if $self->log_level() >= -1;
+
+    _logit($message) if $self->log_level() >= $LOG_LEVEL_DEBUG;
+
+    return 1;
+}
+
+#-----------------------------------------------------------------------------
+
+sub info {
+    my ($self, $message) = @_;
+
+    _logit($message) if $self->log_level() >= $LOG_LEVEL_INFO;
+
+    return 1;
+}
+
+#-----------------------------------------------------------------------------
+
+sub whine {
+    my ($self, $message) = @_;
+
+    warn "$message\n" if $self->log_level() >= $LOG_LEVEL_WARN;
+
+    return 1;
 }
 
 #-----------------------------------------------------------------------------
 
 sub fatal {
     my ($self, $message) = @_;
-    die "$message\n";
+
+    die "$message\n";  ## no critic (RequireCarping)
 }
 
 #-----------------------------------------------------------------------------
@@ -92,7 +113,7 @@ Pinto::Logger - A simple logger
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 AUTHOR
 
