@@ -10,21 +10,16 @@ use namespace::autoclean;
 
 #-----------------------------------------------------------------------------
 
-our $VERSION = '0.008'; # VERSION
+our $VERSION = '0.009'; # VERSION
 
 #-----------------------------------------------------------------------------
 
 has config => (
     is         => 'ro',
     isa        => 'Pinto::Config',
-    lazy_build => 1,
+    required   => 1,
 );
 
-
-sub _build_config {
-    return Pinto::Config->new();
-}
-
 #-----------------------------------------------------------------------------
 
 1;
@@ -41,7 +36,7 @@ Pinto::Role::Configurable - Something that has a configuration
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 AUTHOR
 
