@@ -1,24 +1,23 @@
-# ABSTRACT: Something that makes directory paths
-
 package Pinto::Role::PathMaker;
 
+# ABSTRACT: Something that makes directory paths
+
 use Moose::Role;
 
+use Carp;
 use Path::Class;
-use Try::Tiny;
-
-use Pinto::Exception qw(throw);
+use English qw(-no_match_vars);
 
 use namespace::autoclean;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.040_003'; # VERSION
+our $VERSION = '0.009'; # VERSION
 
 #------------------------------------------------------------------------------
-# Roles
+# Required attributes
 
-with qw(Pinto::Role::Loggable);
+requires 'logger';
 
 #------------------------------------------------------------------------------
 
@@ -28,15 +27,15 @@ sub mkpath {
 
     $path = dir($path) if not eval {$path->isa('Path::Class')};
 
-    throw "$path is not a Path::Class::Dir" if not $path->is_dir;
-    throw "$path is an existing file" if -f $path;
+    croak "$path is not a Path::Class::Dir" if not $path->is_dir();
+    croak "$path is an existing file" if -f $path;
 
     return 0 if -e $path;
 
-    $self->debug("Making directory $path");
+    $self->logger->debug("Making directory $path");
 
-    try   { $path->mkpath }
-    catch { throw "Failed to make directory $path: $_" };
+    eval { $path->mkpath(); 1}
+        or croak "Failed to make directory $path: $EVAL_ERROR";
 
     return 1;
 }
@@ -57,15 +56,15 @@ Pinto::Role::PathMaker - Something that makes directory paths
 
 =head1 VERSION
 
-version 0.040_003
+version 0.009
 
 =head1 METHODS
 
 =head2 mkpath( $path )
 
 Creates a directory at the specified path, including any intervening
-directories.  Throws an exception on failure.  Returns true if a path
-was actually made.  If the path already existed, returns false.
+directories.  Croaks on failure.  Returns true if a path was actually
+made.  If the path already existed, returns false.
 
 =head1 AUTHOR
 
